Author: cwittich
Date: Tue Oct 13 23:49:36 2009
New Revision: 43443
URL: http://svn.reactos.org/svn/reactos?rev=43443&view=rev
Log:
[BDASUP]
-fix some function declarations
Modified:
trunk/reactos/drivers/multimedia/bdasup/bdasup.c
trunk/reactos/drivers/storage/floppy/SOURCES
trunk/reactos/include/ddk/bdasup.h
Modified: trunk/reactos/drivers/multimedia/bdasup/bdasup.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/multimedia/bdasup/…
==============================================================================
--- trunk/reactos/drivers/multimedia/bdasup/bdasup.c [iso-8859-1] (original)
+++ trunk/reactos/drivers/multimedia/bdasup/bdasup.c [iso-8859-1] Tue Oct 13 23:49:36 2009
@@ -691,7 +691,7 @@
BdaPropertyNodeDescriptors(
IN PIRP Irp,
IN KSPROPERTY *pKSProperty,
- OUT GUID *pguidProperty)
+ OUT BDANODE_DESCRIPTOR *pNodeDescriptorProperty)
{
UNIMPLEMENTED
return STATUS_NOT_IMPLEMENTED;
@@ -704,7 +704,7 @@
NTAPI
BdaPropertyNodeEvents(
IN PIRP Irp,
- IN KSPROPERTY *pKSProperty,
+ IN KSP_NODE *pKSProperty,
OUT GUID *pguidProperty)
{
UNIMPLEMENTED
@@ -718,7 +718,7 @@
NTAPI
BdaPropertyNodeMethods(
IN PIRP Irp,
- IN KSPROPERTY *pKSProperty,
+ IN KSP_NODE *pKSProperty,
OUT GUID *pguidProperty)
{
UNIMPLEMENTED
@@ -732,7 +732,7 @@
NTAPI
BdaPropertyNodeProperties(
IN PIRP Irp,
- IN KSPROPERTY *pKSProperty,
+ IN KSP_NODE *pKSProperty,
OUT GUID *pguidProperty)
{
UNIMPLEMENTED
Modified: trunk/reactos/drivers/storage/floppy/SOURCES
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/drivers/storage/floppy/SOU…
==============================================================================
--- trunk/reactos/drivers/storage/floppy/SOURCES [iso-8859-1] (original)
+++ trunk/reactos/drivers/storage/floppy/SOURCES [iso-8859-1] Tue Oct 13 23:49:36 2009
@@ -1,30 +1,28 @@
-# ReactOS Floppy Driver
-# Copyright (C) 2004, Vizzini (vizzini(a)plasmic.com)
-#
-# This program is free software; you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program; if not, write to the Free Software
-# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
-#
-# PROJECT: ReactOS Floppy Driver
-# FILE: SOURCES
-# PURPOSE: SOURCES file for Microsoft DDK build system
-# PROGRAMMER: Vizzini (vizzini(a)plasmic.com)
-# REVISIONS:
-# 15-Feb-2004 vizzini - Created/
-
TARGETNAME=floppy
TARGETTYPE=DRIVER
-TARGETPATH=obj
-TARGETLIBS= $(DDK_LIB_PATH)\csq.lib
-SOURCES= floppy.c csqrtns.c hardware.c readwrite.c ioctl.c
+
MSC_WARNING_LEVEL=/W3 /WX
+
+C_DEFINES=$(C_DEFINES) /DSTDCALL=__stdcall /DDDKAPI=__stdcall /wd4996
+INCLUDES=.; \
+ ../../../.; \
+ ../../../include; \
+ ../../../include; \
+ ../../../include/dxsdk; \
+ ../../../include/dxsdk; \
+ ../../../include/GL; \
+ ../../../include/ndk; \
+ ../../../include/reactos; \
+ ../../../include/reactos; \
+ ../../../include/reactos/mc; \
+ ../../../include/reactos/libs
+
+TARGETLIBS= $(DDK_LIB_PATH)\ntstrsafe.lib
+
+SOURCES=csqrtns.c \
+ floppy.c \
+ hardware.c \
+ ioctl.c \
+ readwrite.c \
+ floppy.rc
+TARGET_DESTINATION=retail
Modified: trunk/reactos/include/ddk/bdasup.h
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/include/ddk/bdasup.h?rev=4…
==============================================================================
--- trunk/reactos/include/ddk/bdasup.h [iso-8859-1] (original)
+++ trunk/reactos/include/ddk/bdasup.h [iso-8859-1] Tue Oct 13 23:49:36 2009
@@ -96,21 +96,21 @@
STDMETHODIMP_(NTSTATUS) BdaPropertyNodeDescriptors(
IN PIRP Irp,
IN KSPROPERTY *pKSProperty,
- OUT GUID *pguidProperty);
+ OUT BDANODE_DESCRIPTOR *pNodeDescriptorProperty);
STDMETHODIMP_(NTSTATUS) BdaPropertyNodeEvents(
IN PIRP Irp,
- IN KSPROPERTY *pKSProperty,
+ IN KSP_NODE *pKSProperty,
OUT GUID *pguidProperty);
STDMETHODIMP_(NTSTATUS) BdaPropertyNodeMethods(
IN PIRP Irp,
- IN KSPROPERTY *pKSProperty,
+ IN KSP_NODE *pKSProperty,
OUT GUID *pguidProperty);
STDMETHODIMP_(NTSTATUS) BdaPropertyNodeProperties(
IN PIRP Irp,
- IN KSPROPERTY *pKSProperty,
+ IN KSP_NODE *pKSProperty,
OUT GUID *pguidProperty);
STDMETHODIMP_(NTSTATUS) BdaPropertyNodeTypes(
Author: dgorbachev
Date: Tue Oct 13 20:43:42 2009
New Revision: 43439
URL: http://svn.reactos.org/svn/reactos?rev=43439&view=rev
Log:
- See if it is a multibyte code page.
- Remove check against zero.
- Fix comments, formatting.
Modified:
trunk/reactos/lib/rtl/unicode.c
Modified: trunk/reactos/lib/rtl/unicode.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/lib/rtl/unicode.c?rev=4343…
==============================================================================
--- trunk/reactos/lib/rtl/unicode.c [iso-8859-1] (original)
+++ trunk/reactos/lib/rtl/unicode.c [iso-8859-1] Tue Oct 13 20:01:55 2009
@@ -417,12 +417,12 @@
ULONG i = 0;
/* Go through all characters of a string */
- while ((OemString->Buffer[i] != 0) &&
- (i < OemString->Length))
+ while (i < OemString->Length)
{
/* Check if it got translated into '?', but source char
wasn't '?' equivalent */
- if ((OemString->Buffer[i] == NlsOemDefaultChar) &&
+ if ((OemString->Buffer[i] != 0) &&
+ (OemString->Buffer[i] == NlsOemDefaultChar) &&
(UnicodeString->Buffer[i] != NlsUnicodeDefaultChar))
{
/* Yes, it means unmappable characters were found */
--- trunk/reactos/lib/rtl/unicode.c [iso-8859-1] (original)
+++ trunk/reactos/lib/rtl/unicode.c [iso-8859-1] Tue Oct 13 20:43:42 2009
@@ -401,40 +401,52 @@
/*
* @implemented
- *
+ *
* NOTES
- * Check the oem-string to match the uincoded-string.
- *
- * Functions who convert unicode strings to oem strings will set a DefaultChar from
- * the OemCodepage when the character are unknown. So check it against the unicode string
- * and return false when the unicode string not contain an TransDefaultChar.
+ * Check the OEM string to match the Unicode string.
+ *
+ * Functions which convert Unicode strings to OEM strings will set a
+ * DefaultChar from the OEM codepage when the characters are unknown.
+ * So check it against the Unicode string and return false when the
+ * Unicode string does not contain a TransDefaultChar.
*/
BOOLEAN
NTAPI
RtlpDidUnicodeToOemWork(IN PCUNICODE_STRING UnicodeString,
IN POEM_STRING OemString)
{
- ULONG i = 0;
-
- /* Go through all characters of a string */
- while (i < OemString->Length)
- {
- /* Check if it got translated into '?', but source char
- wasn't '?' equivalent */
- if ((OemString->Buffer[i] != 0) &&
- (OemString->Buffer[i] == NlsOemDefaultChar) &&
- (UnicodeString->Buffer[i] != NlsUnicodeDefaultChar))
- {
- /* Yes, it means unmappable characters were found */
- return FALSE;
- }
-
- /* Move to the next char */
- i++;
- }
-
- /* All chars were translated successfuly */
- return TRUE;
+ ULONG i = 0;
+
+ if (NlsMbOemCodePageTag == FALSE)
+ {
+ /* single-byte code page */
+ /* Go through all characters of a string */
+ while (i < OemString->Length)
+ {
+ /* Check if it got translated into a default char,
+ * but source char wasn't a default char equivalent
+ */
+ if ((OemString->Buffer[i] == NlsOemDefaultChar) &&
+ (UnicodeString->Buffer[i] != NlsUnicodeDefaultChar))
+ {
+ /* Yes, it means unmappable characters were found */
+ return FALSE;
+ }
+
+ /* Move to the next char */
+ i++;
+ }
+
+ /* All chars were translated successfuly */
+ return TRUE;
+ }
+ else
+ {
+ /* multibyte code page */
+
+ /* FIXME */
+ return TRUE;
+ }
}
/*
Author: fireball
Date: Tue Oct 13 20:01:55 2009
New Revision: 43438
URL: http://svn.reactos.org/svn/reactos?rev=43438&view=rev
Log:
[rtl]
- Fix an out-of-bounds read in RtlpDidUnicodeToOemWorked.
See issue #4888 for more details.
Modified:
trunk/reactos/lib/rtl/unicode.c
Modified: trunk/reactos/lib/rtl/unicode.c
URL: http://svn.reactos.org/svn/reactos/trunk/reactos/lib/rtl/unicode.c?rev=4343…
==============================================================================